@@ -467,13 +467,12 @@ class GaussProcRegTorch():
 
 
 class GPDCtorch(CondIndTest):
-    r"""GPDC conditional independence test based on Gaussian processes and
-        distance correlation. Here with gpytorch implementation.
+    r"""GPDC conditional independence test based on Gaussian processes and distance correlation. Here with gpytorch implementation.
 
     GPDC is based on a Gaussian process (GP) regression and a distance
     correlation test on the residuals [2]_. GP is estimated with gpytorch.
-    The distance correlation test is implemented with
-    cython. Here the null distribution is not analytically available, but can be
+    The distance correlation test is implemented with the dcor package available
+    from pip. Here the null distribution is not analytically available, but can be
     precomputed with the function generate_and_save_nulldists(...) which saves a
     \*.npz file containing the null distribution for different sample sizes.
     This file can then be supplied as null_dist_filename.
