@@ -150,6 +150,7 @@ class Models():
         # Initialize the fit results
         fit_results = {}
         for y in self.Y:
+
             # Construct array of shape (var, time) with first entry being
             # a dummy, second is y followed by joint X and Z (ignore the notation in construct_array)
             array, xyz = \
@@ -164,9 +165,6 @@ class Models():
             if self.data_transform is not None:
                 array = self.data_transform.fit_transform(X=array.T).T
 
-            # Cache array for use in prediction
-            self.observation_array = array
-            self.xyz = xyz
             # Fit the model 
             # Copy and fit the model
             a_model = deepcopy(self.model)
@@ -179,8 +177,11 @@ class Models():
             target_array = array[np.where(xyz==1)[0][0], :]
 
             a_model.fit(X=predictor_array, y=target_array)
+            
             # Cache the results
             fit_results[y] = {}
+            fit_results[y]['observation_array'] = array
+            fit_results[y]['xyz'] = xyz
             fit_results[y]['model'] = a_model
             # Cache the data transform
             fit_results[y]['data_transform'] = deepcopy(self.data_transform)
@@ -254,13 +255,13 @@ class Models():
                     conditions_data = a_transform.transform(X=conditions_data)
 
             # Extract observational Z from stored array
-            z_indices = list(np.where(self.xyz==1)[0][1:])
-            z_array = self.observation_array[z_indices, :].T  
+            z_indices = list(np.where(self.fit_results[y]['xyz']==1)[0][1:])
+            z_array = self.fit_results[y]['observation_array'][z_indices, :].T  
             Tobs = len(z_array)              
 
             if self.conditions is not None and conditions_data is not None:
-                s_indices = list(np.where(self.xyz==2)[0])
-                s_array = self.observation_array[s_indices, :].T  
+                s_indices = list(np.where(self.fit_results[y]['xyz']==2)[0])
+                s_array = self.fit_results[y]['observation_array'][s_indices, :].T  
 
             # Now iterate through interventions (and potentially S)
             for index, dox_vals in enumerate(intervention_data):
@@ -293,133 +294,6 @@ class Models():
         return predicted_array
 
 
-    # def get_general_prediction(self,
-    #             intervention_data=None,
-    #             conditions_data=None,
-    #             pred_params=None,
-    #             ):
-    #     r"""Predict effect of intervention with fitted model.
-
-    #     Uses the model.predict() function of the sklearn model.
-
-    #     Parameters
-    #     ----------
-    #     intervention_data : data object, optional
-    #         Tigramite dataframe object with optional new mask. Only the 
-    #         values for X will be extracted.
-    #     conditions_data : data object, optional
-    #         Tigramite dataframe object with optional new mask. Only the
-    #         values for conditions will be extracted.
-    #     pred_params : dict, optional
-    #         Optional parameters passed on to sklearn prediction function.
-
-    #     Returns
-    #     -------
-    #     Results from prediction.
-    #     """
-
-    #     pred_dict = {}
-    #     for y in self.Y:
-    #         # Print message
-    #         if self.verbosity > 1:
-    #             print("\n## Predicting target %s" % str(y))
-    #             if pred_params is not None:
-    #                 for key in list(pred_params):
-    #                     print("%s = %s" % (key, pred_params[key]))
-    #         # Default value for pred_params
-    #         if pred_params is None:
-    #             pred_params = {}
-    #         # Check this is a valid target
-    #         if y not in self.fit_results:
-    #             raise ValueError("y = %s not yet fitted" % str(y))
-    #         # Construct the array form of the data
-    #         # Check if we've passed a new dataframe object
-    #         observation_array, xyz = \
-    #             self.dataframe.construct_array(X=self.X, Y=[y] + self.Z, Z=self.conditions,
-    #                                            tau_max=self.tau_max,
-    #                                            # mask=self.test_mask,
-    #                                            mask_type=self.mask_type,
-    #                                            cut_off=self.cut_off,
-    #                                            verbosity=self.verbosity)
-
-    #         intervention_array = np.copy(observation_array)
-    #         if intervention_data is not None:
-    #             tmp_array, _ = intervention_data.construct_array(X=self.X, Y=[y] + self.Z, 
-    #                                                      Z=self.conditions,
-    #                                                      tau_max=self.tau_max,
-    #                                                      mask_type=self.mask_type,
-    #                                                      cut_off=self.cut_off,
-    #                                                      verbosity=self.verbosity)
-
-    #             # Only replace X-variables in intervention_array (necessary if lags of
-    #             # X are in Z...)
-    #             for index in np.where(xyz==0)[0]:
-    #                 intervention_array[index] = tmp_array[index]
-
-    #         if self.conditions is not None and conditions_data is not None:
-    #             tmp_array, _ = conditions_data.construct_array(X=self.X, Y=[y] + self.Z, 
-    #                                                      Z=self.conditions,
-    #                                                      tau_max=self.tau_max,
-    #                                                      mask_type=self.mask_type,
-    #                                                      cut_off=self.cut_off,
-    #                                                      verbosity=self.verbosity)
-
-    #             # Only replace condition-variables in intervention_array 
-    #             # (necessary if lags of X are in Z...)
-    #             for index in np.where(xyz==2)[0]:
-    #                 intervention_array[index] = tmp_array[index]
-
-    #         # Transform the data if needed
-    #         a_transform = self.fit_results[y]['data_transform']
-    #         if a_transform is not None:
-    #             intervention_array = a_transform.transform(X=intervention_array.T).T
-    #         # Cache the test array
-    #         self.intervention_array = intervention_array
-    #         # Run the predictor, for Y only the Z-part is used, the first index is y
-    #         predictor_indices =   list(np.where(xyz==0)[0]) \
-    #                             + list(np.where(xyz==1)[0][1:]) \
-    #                             + list(np.where(xyz==2)[0])
-    #         predictor_array = intervention_array[predictor_indices, :].T
-
-    #         pred_dict[y] = self.fit_results[y]['model'].predict(
-    #             X=predictor_array, **pred_params)
-
-    #         # print(pred_dict[y])
-    #         if self.conditions is not None and conditions_data is not None:
-
-    #             a_conditional_model = deepcopy(self.conditional_model)
-
-    #             # Fit Y|do(X) on S
-    #             conditions_array = observation_array[list(np.where(xyz==2)[0])]
-    #             target_array = pred_dict[y]  # array[np.where(xyz==1)[0][0], :]
-
-    #             if a_transform is not None:
-    #                 conditions_array = a_transform.transform(X=conditions_array.T).T
-    #                 target_array = a_transform.transform(X=target_array.T).T
-
-    #             a_conditional_model.fit(X=conditions_array.T, y=target_array)
-    #             self.fit_results[y]['conditional_model'] = a_conditional_model
-
-    #             # Now predict conditional causal effect for new conditions
-    #             tmp_array, _ = conditions_data.construct_array(X=self.X, Y=[y] + self.Z, 
-    #                                                      Z=self.conditions,
-    #                                                      tau_max=self.tau_max,
-    #                                                      mask_type=self.mask_type,
-    #                                                      cut_off=self.cut_off,
-    #                                                      verbosity=self.verbosity)
-
-    #             # Construct conditions array
-    #             new_conditions_array = tmp_array[list(np.where(xyz==2)[0])]
-
-    #             if a_transform is not None:
-    #                 new_conditions_array = a_transform.transform(X=new_conditions_array.T).T
-                
-    #             pred_dict[y] = a_conditional_model.predict(
-    #                 X=new_conditions_array.T, **pred_params)
-
-    #     return pred_dict
-
-
     def get_fit(self, all_parents,
                 selected_variables=None,
                 tau_max=None,
